@@ -340,7 +340,8 @@ class BaseBenchmark(ABC):
 
                 # If the model does not have `label2id` or `id2label`
                 # conversions, then use the defaults
-                if model_label2id is None and model_id2label is None:
+                if (task == 'fill-mask' or
+                        (model_label2id is None and model_id2label is None)):
                     model.config.label2id = self.label2id
                     model.config.id2label = self.id2label
 
@@ -929,7 +930,7 @@ class BaseBenchmark(ABC):
                     except (RuntimeError, ValueError, IndexError) as e:
 
                         # If it is an unknown error, then simply report it
-                        if not str(e).startswith('CUDA out of memory'):
+                        if 'CUDA out of memory' not in str(e):
                             # Garbage collection, to avoid memory issues
                             try:
                                 del model
@@ -952,7 +953,6 @@ class BaseBenchmark(ABC):
                         training_args.per_device_train_batch_size = bs // 2
                         training_args.per_device_eval_batch_size = bs // 2
                         training_args.gradient_accumulation_steps = ga * 2
-                        trainer.args = training_args
 
                         # Garbage collection, to avoid memory issues
                         try:
